@@ -53,6 +53,8 @@
 #include "segatex_audit2allow.h"
 #include "segatex_core.h"
 #include "semodule_core_process.h"
+#include "semanage_core_process.h"
+#include "semanage_core_login_process.h"
 #include "mainwindow.h"
 
 MainWindow::MainWindow(QWidget *parent, const char *name)
@@ -82,9 +84,12 @@ MainWindow::MainWindow(QWidget *parent, const char *name)
 	//needs here to be declared when opening a new window unless segmentation fualt happens...
 	segatex_apply = 0;
 	selinux_yum = 0;
+	selinux_yum_process = 0;
 	selinux_audit2allow = 0;
 	segatex_core_o = 0;
 	semodule_core_process_o = 0;
+	semanage_core_process_o = 0;
+	semanage_core_login_process_o = 0;
 
 	//connect SIGNAL to objects    
 
@@ -100,7 +105,7 @@ MainWindow::MainWindow(QWidget *parent, const char *name)
 	createToolBars();
 	createStatusBar();
 
-	setCaption(tr("segatex-4.00"));
+	setCaption(tr("segatex-4.30"));
 	setIcon(QPixmap::fromMimeSource("icon.png"));
 }
 
@@ -380,6 +385,11 @@ void MainWindow::createActions()
 	connect(selinuxYumAct, SIGNAL(activated()), this, SLOT(yum_selinux()));
 	connect(selinuxYumAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
+	selinuxYumProcessAct = new QAction(tr("&Yum install/update"), 0, this);
+	selinuxYumProcessAct->setStatusTip(tr("Yum install/update SELinux related RPMs."));
+	connect(selinuxYumProcessAct, SIGNAL(activated()), this, SLOT(yum_selinux_process()));
+	connect(selinuxYumProcessAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
+
 	audit2allowAct = new QAction(tr("&Audit2allow"), 0, this);
 	audit2allowAct->setStatusTip(tr("audit2allow"));
 	connect(audit2allowAct, SIGNAL(activated()), this, SLOT(audit2allow()));
@@ -394,6 +404,16 @@ void MainWindow::createActions()
 	semodule_core_processAct->setStatusTip(tr("Modules."));
 	connect(semodule_core_processAct, SIGNAL(activated()), this, SLOT(semodule_core_process()));
 	connect(semodule_core_processAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
+
+	semanage_core_processAct = new QAction(tr("&list objects"), 0, this);
+	semanage_core_processAct->setStatusTip(tr("Semanage login -l user -l boolean -l port -l interface -l fcontext -l translation -l."));
+	connect(semanage_core_processAct, SIGNAL(activated()), this, SLOT(semanage_core_process()));
+	connect(semanage_core_processAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
+
+	semanage_core_login_processAct = new QAction(tr("&semanage login"), 0, this);
+	semanage_core_login_processAct->setStatusTip(tr("Semanage login -a -m -d."));
+	connect(semanage_core_login_processAct, SIGNAL(activated()), this, SLOT(semanage_core_login_process()));
+	connect(semanage_core_login_processAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 }
 
 void MainWindow::createMenus()
@@ -458,7 +478,8 @@ void MainWindow::createMenus()
 
 	segatex_coreAct->addTo(policyMenu);
 	audit2allowAct->addTo(policyMenu);
-	selinuxYumAct->addTo(policyMenu);
+	//selinuxYumAct->addTo(policyMenu);
+	selinuxYumProcessAct->addTo(policyMenu);
 	enforcingAct->addTo(policyMenu);
 	check_selinuxAct->addTo(policyMenu);
 	default_policyAct->addTo(policyMenu);
@@ -466,6 +487,10 @@ void MainWindow::createMenus()
 	manageMenu = new QPopupMenu(this);
 	semodule_core_processAct->addTo(manageMenu);
 
+	semanageMenu = new QPopupMenu(this);
+	semanage_core_processAct->addTo(semanageMenu);
+	semanage_core_login_processAct->addTo(semanageMenu);
+
 	menuBar()->insertItem(tr("&File"), fileMenu);
 	menuBar()->insertItem(tr("&Edit"), editMenu);
 	menuBar()->insertItem(tr("&Windows"), windowsMenu);
@@ -474,10 +499,11 @@ void MainWindow::createMenus()
 	menuBar()->insertSeparator();
 	menuBar()->insertItem(tr("&Policy"), policyMenu);
 	menuBar()->insertItem(tr("&Modules"), manageMenu);
+	menuBar()->insertItem(tr("&Semanage"), semanageMenu);
 
 	menuBar()->insertSeparator();
 	menuBar()->insertItem(tr("Parse&Lines"), parselinesMenu);
-	menuBar()->insertItem(tr("&Selpaw"), selpawMenu);
+	menuBar()->insertItem(tr("Selpa&w"), selpawMenu);
 	menuBar()->insertItem(tr("&Refine"), refineMenu);
 
 	menuBar()->insertSeparator();
@@ -815,7 +841,7 @@ void MainWindow::notice()
 void MainWindow::about()
 {
 	QMessageBox::about(this, tr("About segatex"),
-		tr("<h2>segatex-4.00</h2>"
+		tr("<h2>segatex-4.30</h2>"
 		"<p>Copyright &copy; 2007"
 		"<p>Shintaro Fujiwara."
 		"<p>segatex_suite is a SELinux tool"
@@ -833,6 +859,7 @@ void MainWindow::howtouse()
 		" RPMs.You can audit2allow"
 		" You can analize audit log."
 		" You can manage modules."
+		" You can semanage."
 		" You can generate interfaced policy,by "
 		" Analize audit.log-generate policy."
 		"<p><font color=\"blue\">[segatex_editor]</font>"
@@ -947,6 +974,7 @@ void MainWindow::enforcing()
 	segatex_apply->setActiveWindow();
 }
 //newly added
+
 void MainWindow::yum_selinux()
 {
 	if(!selinux_yum) {
@@ -956,6 +984,15 @@ void MainWindow::yum_selinux()
 	selinux_yum->raise();
 	selinux_yum->setActiveWindow();
 }
+void MainWindow::yum_selinux_process()
+{
+	if(!selinux_yum_process) {
+		selinux_yum_process = new SegatexYumProcess(this);
+	}
+	selinux_yum_process->show();
+	selinux_yum_process->raise();
+	selinux_yum_process->setActiveWindow();
+}
 void MainWindow::audit2allow()
 {
 	if(!selinux_audit2allow) {
@@ -983,3 +1020,21 @@ void MainWindow::semodule_core_process()
 	semodule_core_process_o->raise();
 	semodule_core_process_o->setActiveWindow();
 }
+void MainWindow::semanage_core_process()
+{
+	if(!semanage_core_process_o) {
+		semanage_core_process_o = new SemanageCoreProcess(this);
+	}
+	semanage_core_process_o->show();
+	semanage_core_process_o->raise();
+	semanage_core_process_o->setActiveWindow();
+}
+void MainWindow::semanage_core_login_process()
+{
+	if(!semanage_core_login_process_o) {
+		semanage_core_login_process_o = new SemanageCoreLoginProcess(this);
+	}
+	semanage_core_login_process_o->show();
+	semanage_core_login_process_o->raise();
+	semanage_core_login_process_o->setActiveWindow();
+}
